# UESURIBuilder - Class for creating Core UESURI.
#
# This is an example, how can be an UESURI created:
#
# uri = UESURIBuilder.setTerritoryId(123).setArtifactCode("artCode").setObjectId("456").toUESURI
#
# <tt><b>author</b></tt> uni429
#
# <tt><b>since</b></tt> UES6-00
class Ues::Core::Commons::Uri::UESURIBuilder

  @uriBuilder = nil

  # Creates new instance of UESURIBuilder.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES7-04
  def initialize()
    @uriBuilder = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.core.commons.uri.UESURIBuilder.java_class)
  end

  # Parses specified string into UESURIBuilder instance.
  #
  # <tt><b>param</b></tt> uri Parsed UESURI.
  #
  # <tt><b>return</b></tt> Instance of UESURIBuilder.
  #
  # <tt><b>throws</b></tt> InvalidFormatRTException When resolved String contains invalid or unsupported format of UESURI.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.parseURI(uri)
    builder = UESURIBuilder.new
    builder.parseURI(uri)
    return builder
  end
  class << Ues::Core::Commons::Uri::UESURIBuilder
    alias parse_URI parseURI
  end

  def parseURI(uri) #:nodoc:
    @uriBuilder.parseURI(uri.to_s)
    return self
  end
  alias parse_uri parseURI #:nodoc:

  # Sets authority Id for the new UESURI.
  #
  # <tt><b>param</b></tt> authorityId Authority Id.
  #
  # <tt><b>return</b></tt> Instance of UESURIBuilder.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.setAuthorityId(authorityId)
    builder = UESURIBuilder.new
    builder.setAuthorityId(authorityId)
    return builder
  end
  class << Ues::Core::Commons::Uri::UESURIBuilder
    alias authority_id= setAuthorityId
  end

  def setAuthorityId(authorityId) #:nodoc:
    @uriBuilder.setAuthorityId(authorityId.to_s)
    return self
  end
  alias authority_id= setAuthorityId #:nodoc:

  # Sets authority code for the new UESURI.
  #
  # <tt><b>param</b></tt> authorityCode Authority code.
  #
  # <tt><b>return</b></tt> Instance of UESURIBuilder.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.setAuthorityCode(authorityCode)
    builder = UESURIBuilder.new
    builder.setAuthorityCode(authorityCode)
    return builder
  end
  class << Ues::Core::Commons::Uri::UESURIBuilder
    alias authority_code= setAuthorityCode
  end

  def setAuthorityCode(authorityCode) #:nodoc:
    @uriBuilder.setAuthorityCode(authorityCode.to_s)
    return self
  end
  alias authority_code= setAuthorityCode #:nodoc:

  # Sets role Id for the new UESURI.
  #
  # <tt><b>param</b></tt> roleId Role Id.
  #
  # <tt><b>return</b></tt> Instance of UESURIBuilder.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.setRoleId(roleId)
    builder = UESURIBuilder.new
    builder.setRoleId(roleId)
    return builder
  end
  class << Ues::Core::Commons::Uri::UESURIBuilder
    alias role_id= setRoleId
  end

  def setRoleId(roleId) #:nodoc:
    @uriBuilder.setRoleId(roleId.to_s)
    return self
  end
  alias role_id= setRoleId #:nodoc:

  # Sets role code for the new UESURI.
  #
  # <tt><b>param</b></tt> roleCode Role code.
  #
  # <tt><b>return</b></tt> Instance of UESURIBuilder.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.setRoleCode(roleCode)
    builder = UESURIBuilder.new
    builder.setRoleCode(roleCode)
    return builder
  end
  class << Ues::Core::Commons::Uri::UESURIBuilder
    alias role_code= setRoleCode
  end

  def setRoleCode(roleCode) #:nodoc:
    @uriBuilder.setRoleCode(roleCode.to_s)
    return self
  end
  alias role_code= setRoleCode #:nodoc:

  # Sets territory Id for the new UESURI.
  #
  # <tt><b>param</b></tt> territoryId Territory Id.
  #
  # <tt><b>return</b></tt> Reference to this UESURIBuilder object.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.setTerritoryId(territoryId)
    builder = UESURIBuilder.new
    builder.setTerritoryId(territoryId)
    return builder
  end
  class << Ues::Core::Commons::Uri::UESURIBuilder
    alias territory_id= setTerritoryId
  end

  def setTerritoryId(territoryId) #:nodoc:
    @uriBuilder.setTerritoryId(territoryId.to_s)
    return self
  end
  alias territory_id= setTerritoryId #:nodoc:

  # Sets territory code for new created UESURI.
  #
  # <tt><b>param</b></tt> territoryCode Territory code.
  #
  # <tt><b>return</b></tt> Reference to this UESURIBuilder object.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.setTerritoryCode(territoryCode)
    builder = UESURIBuilder.new
    builder.setTerritoryCode(territoryCode)
    return builder
  end
  class << Ues::Core::Commons::Uri::UESURIBuilder
    alias territory_code= setTerritoryCode
  end

  def setTerritoryCode(territoryCode) #:nodoc:
    @uriBuilder.setTerritoryCode(territoryCode.to_s)
    return self
  end
  alias territory_code= setTerritoryCode #:nodoc:

  # Sets entity part for the new UESURI.
  #
  # <tt><b>param</b></tt> entityPart Entity part.
  #
  # <tt><b>return</b></tt> Reference to this UESURIBuilder object.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.setEntityPart(entityPart)
    builder = UESURIBuilder.new
    builder.setEntityPart(entityPart)
    return builder
  end
  class << Ues::Core::Commons::Uri::UESURIBuilder
    alias entity_part= setEntityPart
  end

  def setEntityPart(entityPart) #:nodoc:
    @uriBuilder.setEntityPart(entityPart.to_s)
    return self
  end
  alias entity_part= setEntityPart #:nodoc:

  # Sets use case Id for the new UESURI.
  #
  # <tt><b>param</b></tt> useCaseId Use case Id.
  #
  # <tt><b>return</b></tt> Reference to this UESURIBuilder object.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.setUseCaseId(useCaseId)
    builder = UESURIBuilder.new
    builder.setUseCaseId(useCaseId)
    return builder
  end
  class << Ues::Core::Commons::Uri::UESURIBuilder
    alias use_case_id= setUseCaseId
  end

  def setUseCaseId(useCaseId) #:nodoc:
    @uriBuilder.setUseCaseId(useCaseId.to_s)
    return self
  end
  alias use_case_id= setUseCaseId #:nodoc:

  # Sets use case code for the new UESURI.
  #
  # <tt><b>param</b></tt> useCaseCode Use case code.
  #
  # <tt><b>return</b></tt> Reference to this UESURIBuilder object.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.setUseCaseCode(useCaseCode)
    builder = UESURIBuilder.new
    builder.setUseCaseCode(useCaseCode)
    return builder
  end
  class << Ues::Core::Commons::Uri::UESURIBuilder
    alias use_case_code= setUseCaseCode
  end

  def setUseCaseCode(useCaseCode) #:nodoc:
    @uriBuilder.setUseCaseCode(useCaseCode.to_s)
    return self
  end
  alias use_case_code= setUseCaseCode #:nodoc:

   # Sets use case action for the new UESURI.
   #
   # <tt><b>param</b></tt> action Use case action.
   #
   # <tt><b>return</b></tt> Reference to this UESURIBuilder object.
   #
   # <tt><b>since</b></tt> UES8-08
  def self.setAction(action)
    builder = UESURIBuilder.new
    builder.setAction(action)
    return builder
  end
  class << Ues::Core::Commons::Uri::UESURIBuilder
    alias action= setAction
  end
  
  def setAction(action) #:nodoc:
    @uriBuilder.setAction(action.to_s)
    return self
  end
  alias action= setAction #:nodoc:

  # Sets parameters for the new UESURI.
  #
  # <tt><b>param</b></tt> parameters UESURI parameters.
  #
  # <tt><b>return</b></tt> Reference to this UESURIBuilder object.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.setParameters(parameters)
    builder = UESURIBuilder.new
    builder.setParameters(parameters)
    return builder
  end
  class << Ues::Core::Commons::Uri::UESURIBuilder
    alias parameters= setParameters
  end
  
  def setParameters(parameters) #:nodoc:
    @uriBuilder.setParameters(parameters)
    return self
  end
  alias parameters= setParameters #:nodoc:

  # Sets fragment for the new UESURI.
  #
  # <tt><b>param</b></tt> fragment Fragment.
  #
  # <tt><b>return</b></tt> Reference to this UESURIBuilder object.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.setFragment(fragment)
    builder = UESURIBuilder.new
    builder.setFragment(fragment)
    return builder
  end
  class << Ues::Core::Commons::Uri::UESURIBuilder
    alias fragment= setFragment
  end

  def setFragment(fragment) #:nodoc:
    @uriBuilder.setFragment(fragment.to_s)
    return self
  end
  alias fragment= setFragment #:nodoc:

  # Sets artifact Id for the new UESURI.
  #
  # <tt><b>param</b></tt> artifactId Artifact Id.
  #
  # <tt><b>return</b></tt> Reference to this UESURIBuilder object.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.setArtifactId(artifactId)
    builder = UESURIBuilder.new
    builder.setArtifactId(artifactId)
    return builder
  end
  class << Ues::Core::Commons::Uri::UESURIBuilder
    alias artifact_id= setArtifactId
  end

  def setArtifactId(artifactId) #:nodoc:
    @uriBuilder.setArtifactId(artifactId.to_s)
    return self
  end
  alias artifact_id= setArtifactId #:nodoc:

  # Sets artifact code for the new UESURI.
  #
  # <tt><b>param</b></tt> artifactCode Artifact code.
  #
  # <tt><b>return</b></tt> Reference to this UESURIBuilder object.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.setArtifactCode(artifactCode)
    builder = UESURIBuilder.new
    builder.setArtifactCode(artifactCode)
    return builder
  end
  class << Ues::Core::Commons::Uri::UESURIBuilder
    alias artifact_code= setArtifactCode
  end

  def setArtifactCode(artifactCode) #:nodoc:
    @uriBuilder.setArtifactCode(artifactCode.to_s)
    return self
  end
  alias artifact_code= setArtifactCode #:nodoc:

  # Sets object Id for the new UESURI.
  #
  # <tt><b>param</b></tt> objectId Object Id.
  #
  # <tt><b>return</b></tt> Reference to this UESURIBuilder object.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.setObjectId(objectId)
    builder = UESURIBuilder.new
    builder.setObjectId(objectId)
    return builder
  end
  class << Ues::Core::Commons::Uri::UESURIBuilder
    alias object_id= setObjectId
  end

  def setObjectId(objectId) #:nodoc:
    @uriBuilder.setObjectId(objectId.to_s)
    return self
  end
  alias object_id= setObjectId #:nodoc:

  # Sets object code for the new UESURI.
  #
  # <tt><b>param</b></tt> objectCode Object code.
  #
  # <tt><b>return</b></tt> Reference to this UESURIBuilder object.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.setObjectCode(objectCode)
    builder = UESURIBuilder.new
    builder.setObjectCode(objectCode)
    return builder
  end
  class << Ues::Core::Commons::Uri::UESURIBuilder
    alias object_code= setObjectCode
  end

  def setObjectCode(objectCode) #:nodoc:
    @uriBuilder.setObjectCode(objectCode.to_s)
    return self
  end
  alias object_code= setObjectCode #:nodoc:

  # Creates new instance of UESURI.
  #
  # <tt><b>return</b></tt> Instance of UESURI.
  #
  # <tt><b>throws</b></tt> InvalidFormatRTException When created UESURI has no scheme or no artifact part specified.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def toUESURI()
    return Ues::Core::Commons::Uri::UESURI.new(@uriBuilder.toUESURI())
  end
  alias to_uesuri toUESURI

end
